@@ -1,9 +1,9 @@
 # fields/checksums -- lintian check script (rewrite) -*- perl -*-
 #
-# Copyright (C) 2004 Marc Brockschmidt
+# Copyright © 2004 Marc Brockschmidt
 #
 # Parts of the code were taken from the old check script, which
-# was Copyright (C) 1998 Richard Braakman (also licensed under the
+# was Copyright © 1998 Richard Braakman (also licensed under the
 # GPL 2 or higher)
 #
 # This program is free software; you can redistribute it and/or modify
@@ -24,21 +24,23 @@
 
 package Lintian::fields::checksums;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Moo;
+use namespace::clean;
 
-with('Lintian::Check');
+with 'Lintian::Check';
 
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     $self->tag('no-strong-digests-in-dsc')
-      unless $info->field('checksums-sha256');
+      unless $processable->field('checksums-sha256');
 
     return;
 }
