@@ -2,7 +2,8 @@
 
 # somewhat of a misnomer -- it doesn't only check menus
 
-# Copyright (C) 1998 Christian Schwarz
+# Copyright © 1998 Christian Schwarz
+# Copyright © 2018 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,14 +23,16 @@
 
 package Lintian::menus;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
+use Path::Tiny;
+
 use Lintian::Data;
 use Lintian::Spelling
   qw(check_spelling check_spelling_picky $known_shells_regex);
-use Lintian::Util qw(file_is_encoded_in_non_utf8 strip);
 
 use Moo;
 use namespace::clean;
@@ -259,25 +262,27 @@ sub check_doc_base_file {
     my $group = $self->group;
 
     my $dbfile = $dbpath->basename;
-    my $line = file_is_encoded_in_non_utf8($dbpath->unpacked_path);
-    if ($line) {
-        $self->tag('doc-base-file-uses-obsolete-national-encoding',
-            "$dbfile:$line");
+
+    unless ($dbpath->is_valid_utf8) {
+        $self->tag('doc-base-file-uses-obsolete-national-encoding', $dbfile);
+        return;
     }
 
+    my $contents = $dbpath->decoded_utf8;
+    my @lines = split(/\n/, $contents);
+
     my $knownfields = \%KNOWN_DOCBASE_MAIN_FIELDS;
     my ($field, @vals);
     my %sawfields;        # local for each section of control file
     my %sawformats;       # global for control file
-    $line           = 0;  # global
+    my $line           = 0;  # global
 
-    open(my $fd, '<', $dbpath->unpacked_path);
-
-    while (<$fd>) {
-        chomp;
+    my $position = 1;
+    while (defined(my $string = shift @lines)) {
+        chomp $string;
 
         # New field.  check previous field, if we have any.
-        if (/^(\S+)\s*:\s*(.*)$/) {
+        if ($string =~ /^(\S+)\s*:\s*(.*)$/) {
             my (@new) = ($1, $2);
             if ($field) {
                 $self->check_doc_base_field(
@@ -288,19 +293,20 @@ sub check_doc_base_file {
             }
             $field = lc $new[0];
             @vals  = ($new[1]);
-            $line  = $.;
+            $line  = $position;
 
             # Continuation of previously defined field.
-        } elsif ($field && /^\s+\S/) {
-            push(@vals, $_);
+        } elsif ($field && $string =~ /^\s+\S/) {
+            push(@vals, $string);
 
             # All tags will be reported on the last continuation line of the
             # doc-base field.
-            $line  = $.;
+            $line  = $position;
 
             # Sections' separator.
-        } elsif (/^(\s*)$/) {
-            $self->tag('doc-base-file-separator-extra-whitespace',"$dbfile:$.")
+        } elsif ($string =~ /^(\s*)$/) {
+            $self->tag('doc-base-file-separator-extra-whitespace',
+                "$dbfile:$position")
               if $1;
             next unless $field; # skip successive empty lines
 
@@ -324,8 +330,11 @@ sub check_doc_base_file {
 
             # Everything else is a syntax error.
         } else {
-            $self->tag('doc-base-file-syntax-error', "$dbfile:$.");
+            $self->tag('doc-base-file-syntax-error', "$dbfile:$position");
         }
+
+    } continue {
+        ++$position;
     }
 
     # Check the last field/section of the control file.
@@ -340,11 +349,9 @@ sub check_doc_base_file {
     }
 
     # Make sure we saw at least one format.
-    $self->tag('doc-base-file-no-format-section', "$dbfile:$.")
+    $self->tag('doc-base-file-no-format-section', $dbfile)
       unless %sawformats;
 
-    close($fd);
-
     return;
 }
 
@@ -413,7 +420,10 @@ sub check_doc_base_field {
         # Format field.
     } elsif ($field eq 'format') {
         my $format = join(' ', @$vals);
-        strip($format);
+
+        # trim both ends
+        $format =~ s/^\s+|\s+$//g;
+
         $format = lc $format;
         $self->tag('doc-base-file-unknown-format', "$dbfile:$line", $format)
           unless $known_doc_base_formats{$format};
